@@ -1,14 +1,12 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Data structure "epidata" representing the SIR event history of a fixed
 ### geo-referenced population (e.g., farms, households) for twinSIR() analysis
 ###
-### Copyright (C) 2008-2010, 2012, 2014-2017 Sebastian Meyer
-### $Revision: 2044 $
-### $Date: 2017-11-16 15:34:00 +0100 (Thu, 16. Nov 2017) $
+### Copyright (C) 2008-2010, 2012, 2014-2018, 2020 Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 ## CAVE:
@@ -177,7 +175,7 @@ as.epidata.default <- function(data, id.col, start.col, stop.col, atRiskY.col,
         }
         if (is.character(colidx)) {
             colidx <- match(colidx, colnames(data))
-            if (any(is.na(colidx))) {
+            if (anyNA(colidx)) {
                 stop("'", colarg, " = ", deparse(cl[[colarg]]), "': ",
                      "column does not exist in 'data'")
             }
@@ -683,13 +681,21 @@ summary.epidata <- function (object, ...)
                            idvar = "id")
             attr(.res, "reshapeWide") <- NULL
             if ("time.I" %in% names(.res)) {
-                .res
+                .res[c("id", "time.I", "time.R")]  # ensure natural order
             } else { # degenerate case: only R (and S) events in data
                 cbind(.res[1L], "time.I" = NA_real_, .res[-1L])
             }
         } else {
-            rowsPerId <- table(eventTable[["id"]])
+            eventTable3 <- if (m > 0) { # workaround for initially infected
+                rbind(data.frame(id = initiallyInfected, time = NA_real_, type = "I",
+                                 row.names = NULL, check.names = FALSE,
+                                 stringsAsFactors = FALSE),
+                      eventTable)
+            } else eventTable
+            rowsPerId <- table(eventTable3[["id"]])
             modulo3 <- rowsPerId %% 3
+            ## if this is 1, we need to append NAs for R and S events
+            ## if 2, only append NA for the final S (occurs for SIRS, not SIS)
             rest1 <- modulo3 == 1
             rest12 <- modulo3 >= 1
             missingR <-
@@ -702,7 +708,7 @@ summary.epidata <- function (object, ...)
                            time = rep(NA_real_, sum(rest12)),
                            type = rep("S", sum(rest12)), row.names = NULL,
                            check.names = FALSE, stringsAsFactors = FALSE)
-            eventTable3 <- rbind(eventTable, missingR, missingS)
+            eventTable3 <- rbind(eventTable3, missingR, missingS)
             eventTable3 <- eventTable3[order(eventTable3[["id"]]),]
             .res <- data.frame(
                 eventTable3[eventTable3$type == "I", c("id", "time")],
@@ -725,7 +731,8 @@ summary.epidata <- function (object, ...)
     ###            evolution of numbers of susceptibles, infectious and removed
     counters <- eventTable[order(eventTable[["time"]]),c("time", "type", "id")]
     init <- data.frame(time = attr(object, "timeRange")[1L],
-                       type = NA_character_, id = NA_character_,
+                       type = factor(NA_character_, levels(counters$type)),
+                       id = factor(NA_character_, levels(counters$id)),
                        nSusceptible = n, nInfectious = m, nRemoved = 0L)
     cumulatedReSusceptibility <- cumsum(counters[["type"]] == "S")
     cumulatedInfections <- cumsum(counters[["type"]] == "I")
