@@ -2,14 +2,11 @@
 ### Endemic-epidemic modelling for univariate or multivariate
 ### time series of infectious disease counts (data class "sts")
 ###
-### Copyright (C) 2010-2012 Michaela Paul, 2012-2016,2019-2022 Sebastian Meyer
+### Copyright (C) 2010-2012 Michaela Paul, 2012-2016,2019-2023 Sebastian Meyer
 ###
 ### This file is part of the R package "surveillance",
 ### free software under the terms of the GNU General Public License, version 2,
 ### a copy of which is available at https://www.R-project.org/Licenses/.
-###
-### $Revision: 2874 $
-### $Date: 2022-08-05 17:15:48 +0200 (Fri, 05. Aug 2022) $
 ################################################################################
 
 ## Error message issued in loglik, score and fisher functions upon NA parameters
@@ -173,7 +170,7 @@ setControl <- function (control, stsObj)
   defaultControl <- eval(formals(hhh4)$control)
   environment(defaultControl$ar$f) <- environment(defaultControl$ne$f) <-
       environment(defaultControl$end$f) <- .GlobalEnv
-  control <- modifyList(defaultControl, control)
+  control <- modifyList(defaultControl, control, keep.null = TRUE)
 
   ## check that component specifications are list objects
   for (comp in c("ar", "ne", "end")) {
@@ -261,7 +258,7 @@ setControl <- function (control, stsObj)
           if (!identical(dim(control[[comp]]$offset), dim(stsObj)))
               stop("'control$",comp,"$offset' must be a numeric matrix of size ",
                    nTime, "x", nUnit)
-          if (any(is.na(control[[comp]]$offset)))
+          if (anyNA(control[[comp]]$offset))
               stop("'control$",comp,"$offset' must not contain NA values")
       } else if (!identical(as.numeric(control[[comp]]$offset), 1)) {
           stop("'control$",comp,"$offset' must either be 1 or a numeric ",
@@ -1897,24 +1894,6 @@ updateParams_nlminb <- function (start, ll, sc, fi, ..., control)
          convergence=res$convergence, message=res$message)
 }
 
-updateParams_nr <- function (start, ll, sc, fi, ..., control)
-{
-    ## objective function
-    llscfi <- function (x, ...) {
-        loglik <- ll(x, ...)
-        attr(loglik, "score") <- sc(x, ...)
-        attr(loglik, "fisher") <- fi(x, ...)
-        loglik
-    }
-    ## run the optimization
-    res <- newtonRaphson(start, llscfi, ...,
-                         control=control, verbose=control$verbose)
-    ## Done
-    list(par=res$coefficients, ll=res$loglikelihood,
-         rel.tol=getRelDiff(res$coefficients, start),
-         convergence=res$convergence, message=res$message)
-}
-
 updateParams_nlm <- function (start, ll, sc, fi, ..., control)
 {
     ## objective function
@@ -1927,7 +1906,7 @@ updateParams_nlm <- function (start, ll, sc, fi, ..., control)
     ## run the optimization
     res <- do.call("nlm", args=c(alist(p=start, f=negllscfi, ...), control))
     ## Done
-    list(par=res$estimate, ll=-res$minimum,
+    list(par=setNames(res$estimate, names(start)), ll=-res$minimum,
          rel.tol=getRelDiff(res$estimate, start),
          convergence=as.numeric(res$code>2), message=res$message)
     ## nlm returns convergence status in $code, 1-2 indicate convergence,
@@ -1975,8 +1954,6 @@ defaultOptimControl <- function (method = "nlminb", lower = -Inf, upper = Inf,
     if (is.null(iter.max)) iter.max <- 20 + 480*(method=="Nelder-Mead")
     lowVerbose <- verbose %in% 0:2
     luOptimMethod <- method %in% c("Brent", "L-BFGS-B")
-    defaults.nr <- list(scoreTol=1e-5, paramTol=1e-7, F.inc=0.01, stepFrac=0.5,
-                        niter=iter.max, verbose=verbose)
     defaults.nlminb <- list(iter.max=iter.max, scale=1, lower=lower, upper=upper,
                             trace=if(lowVerbose) c(0,0,5)[verbose+1] else 1)
     defaults.nlm <- list(iterlim=iter.max, check.analyticals=FALSE,
@@ -1984,7 +1961,7 @@ defaultOptimControl <- function (method = "nlminb", lower = -Inf, upper = Inf,
     defaults.optim <- list(maxit=iter.max, fnscale=-1, trace=max(0,verbose-1),
                            lower=if (luOptimMethod) lower else -Inf,
                            upper=if (luOptimMethod) upper else Inf)
-    switch(method, "nr" = defaults.nr, "nlm" = defaults.nlm,
+    switch(method, "nlm" = defaults.nlm,
            "nlminb" = defaults.nlminb, defaults.optim)
 }
 
@@ -2019,7 +1996,7 @@ fitHHH <- function(theta, sd.corr, model,
                   " (dim(", deparse(substitute(start)), ")=1)")
       }
       list(paste("updateParams",
-                 if (method %in% c("nlminb", "nlm", "nr"))
+                 if (method %in% c("nlminb", "nlm"))
                  method else "optim", sep="_"),
            control = setOptimControl(method, cntrl, ...))
   }
@@ -2051,9 +2028,10 @@ fitHHH <- function(theta, sd.corr, model,
 
   ## Let's go
   if (verbose>0) {
-      cat(as.character(Sys.time()), ":",
-          if (dimRE == 0) "Optimization of regression parameters" else
-          "Iterative optimization of regression & variance parameters", "\n")
+      if (verbose > 1) utils::timestamp()
+      cat(if (dimRE == 0) "Optimization of regression parameters"
+          else "Iterative optimization of regression & variance parameters",
+          "\n", sep = "")
   }
 
   if (dimRE == 0) { # optimization of regression coefficients only
@@ -2121,9 +2099,9 @@ fitHHH <- function(theta, sd.corr, model,
   }
 
   if(verbose > 0) {
-    cat("\n")
-    cat(as.character(Sys.time()), ":", if (convergence==0)
-        "Optimization converged" else "Optimization DID NOT CONVERGE", "\n\n")
+    cat("\n", if (convergence==0) "Optimization converged"
+        else "Optimization DID NOT CONVERGE", "\n", sep = "")
+    if (verbose > 1) utils::timestamp()
   }
 
   ll     <- penLogLik(theta, sd.corr, model)
