@@ -1,13 +1,11 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
+### Standard methods for "hhh4" fits
 ###
-### Standard methods for hhh4-fits
+### Copyright (C) 2010-2012 Michaela Paul, 2012-2023 Sebastian Meyer
 ###
-### Copyright (C) 2010-2012 Michaela Paul, 2012-2018 Sebastian Meyer
-### $Revision: 2048 $
-### $Date: 2018-01-16 16:14:52 +0100 (Tue, 16. Jan 2018) $
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 ## NOTE: we also apply print.hhh4 in print.summary.hhh4()
@@ -57,8 +55,8 @@ print.hhh4 <- function (x, digits = max(3, getOption("digits")-3), ...)
 }
 .printREmat <- function (REmat, digits = 4)
 {
-    V <- round(diag(REmat), digits=digits)
-    corr <- round(attr(REmat, "correlation"), digits=digits)
+    V <- format(diag(REmat), digits=digits)
+    corr <- format(attr(REmat, "correlation"), digits=digits)
     corr[upper.tri(corr,diag=TRUE)] <- ""
     V.corr <- cbind(V, corr, deparse.level=0)
     colnames(V.corr) <- c("Var", "Corr", rep.int("", ncol(corr)-1L))
@@ -73,7 +71,7 @@ summary.hhh4 <- function (object, maxEV = FALSE, ...)
 	return(invisible(object))
     }
     ret <- c(object[c("call", "convergence", "dim", "loglikelihood", "margll",
-                      "lags", "nTime", "nUnit")],
+                      "lags", "nObs", "nTime", "nUnit")],
              list(fixef = fixef.hhh4(object, se=TRUE, ...),
                   ranef = ranef.hhh4(object, ...),
                   REmat = .getREmat(object),
@@ -87,12 +85,13 @@ summary.hhh4 <- function (object, maxEV = FALSE, ...)
 print.summary.hhh4 <- function (x, digits = max(3, getOption("digits")-3), ...)
 {
     ## x$convergence is always TRUE if we have a summary
-    print.hhh4(x) # also works for summary.hhh4-objects
+    print.hhh4(x, digits = digits) # also works for summary.hhh4-objects
 
     if (!is.null(x$maxEV_range))
         cat("Epidemic dominant eigenvalue: ",
             paste(sprintf("%.2f", x$maxEV_range), collapse = " -- "), "\n\n")
     if(x$dim["random"]==0){
+        ## format(x$AIC,digits=4) would often yield no decimal digits (big AIC)
         cat('Log-likelihood:  ',round(x$loglikelihood,digits=digits-2),'\n')
         cat('AIC:             ',round(x$AIC,digits=digits-2),'\n')
         cat('BIC:             ',round(x$BIC,digits=digits-2),'\n\n')
@@ -102,6 +101,8 @@ print.summary.hhh4 <- function (x, digits = max(3, getOption("digits")-3), ...)
     }
     cat('Number of units:       ', x$nUnit, '\n')
     cat('Number of time points: ', x$nTime, '\n')
+    if ((nOmit <- x$nTime * x$nUnit - x$nObs) > 0)
+        cat("  (", nOmit, " observations excluded due to missingness)\n", sep = "")
     if (!is.null(x$lags)) { # only available since surveillance 1.8-0
         if (!is.na(x$lags["ar"]) && x$lags["ar"] != 1)
             cat("Non-default autoregressive lag:  ", x$lags[["ar"]], "\n")
@@ -130,7 +131,7 @@ logLik.hhh4 <- function(object, ...)
     }
     attr(val, "df") <- if (object$dim["random"])
         NA_integer_ else object$dim[["fixed"]]  # use "[[" to drop the name
-    attr(val, "nobs") <- nobs.hhh4(object)
+    attr(val, "nobs") <- nobs(object)
     class(val) <- "logLik"
     val
 }
@@ -212,10 +213,13 @@ getCoefIdxRenamed <- function (coefnames, reparamPsi=TRUE, idx2Exp=NULL,
         idxPsi
     } else NULL
 
-    ## indexes of sine-cosine coefficients
+    ## indexes of *pairs* of sine-cosine coefficients
     idxAS <- if (amplitudeShift) {
-        idxAS <- sort(c(grep(".sin(", coefnames, fixed=TRUE),
-                        grep(".cos(", coefnames, fixed=TRUE)))
+        idx_sin <- grep(".sin(", coefnames, fixed=TRUE)
+        idx_cos <- match(sub(".sin(", ".cos(", coefnames[idx_sin], fixed=TRUE),
+                         coefnames)
+        if (anyNA(idx_cos)) stop("failed to detect sine-cosine pairs")
+        idxAS <- c(rbind(idx_sin, idx_cos))  # pairwise coefficients
         names(idxAS) <- sub(".sin", ".A", coefnames[idxAS], fixed=TRUE)
         names(idxAS) <- sub(".cos", ".s", names(idxAS), fixed=TRUE)
         idxAS
@@ -249,25 +253,34 @@ fixef.hhh4 <- function (object,...)
     } else NULL
 }
 
-ranef.hhh4 <- function (object, tomatrix = FALSE, ...)
+ranef.hhh4 <- function (object, tomatrix = FALSE, intercept = FALSE, ...)
 {
     if (object$dim[2L] > 0){
         ranefvec <- tail(coef.hhh4(object, ...), object$dim[2L])
     } else return(NULL)
+    if (intercept) tomatrix <- TRUE
     if (!tomatrix) return(ranefvec)
 
     ## transform to a nUnits x c matrix (c %in% 1:3)
-    model <- terms.hhh4(object)
+    model <- terms(object)
     idxRE <- model$indexRE
     idxs <- unique(idxRE)
-    names(idxs) <- model$namesFE[idxs]
-    mat <- sapply(idxs, function (idx) {
+    mat <- vapply(X = idxs, FUN = function (idx) {
         RE <- ranefvec[idxRE==idx]
         Z <- model$terms["Z.intercept",][[idx]]
         "%m%" <- get(model$terms["mult",][[idx]])
-        Z %m% RE
-    })
-    rownames(mat) <- colnames(model$response)
+        c(Z %m% RE)
+    }, FUN.VALUE = numeric(model$nUnits), USE.NAMES = FALSE)
+    dimnames(mat) <- list(
+        colnames(model$response),
+        model$namesFE[match(idxs, model$indexFE)]
+    )
+
+    if (intercept) {
+        FE <- object$coefficients[colnames(mat)]
+        mat <- t(t(mat) + FE)
+    }
+
     return(mat)
 }
 
@@ -302,8 +315,8 @@ predict.hhh4 <- function(object, newSubset = object$control$subset,
         ## we can extract fitted means from object
         object$fitted.values[m,,drop=FALSE]
     } else { ## means for time points not fitted (not part of object$control$subset)
-        predicted <- meanHHH(coef.hhh4(object, reparamPsi=FALSE),
-                             terms.hhh4(object),
+        predicted <- meanHHH(object$coefficients,
+                             terms(object),
                              subset=newSubset)
         if (type=="response") predicted$mean else {
             type <- match.arg(type, names(predicted))
@@ -426,7 +439,7 @@ hhh4coef2start <- function (fit)
 coeflist.hhh4 <- function (x, ...)
 {
     ## determine number of parameters by parameter group
-    model <- terms.hhh4(x)
+    model <- terms(x)
     dim.fe.group <- unlist(model$terms["dim.fe",], recursive = FALSE, use.names = FALSE)
     dim.re.group <- unlist(model$terms["dim.re",], recursive = FALSE, use.names = FALSE)
     nFERE <- lapply(X = list(fe = dim.fe.group, re = dim.re.group),
@@ -454,7 +467,7 @@ coeflist.hhh4 <- function (x, ...)
 ## extract estimated overdispersion in dnbinom() parametrization (and as matrix)
 psi2size.hhh4 <- function (object, subset = object$control$subset, units = NULL)
 {
-    size <- sizeHHH(object$coefficients, terms.hhh4(object), subset = subset)
+    size <- sizeHHH(object$coefficients, terms(object), subset = subset)
     if (!is.null(size) && !is.null(units)) {
         if (is.null(subset)) {
             warning("ignoring 'units' (not compatible with 'subset = NULL')")
@@ -511,7 +524,7 @@ formula.hhh4 <- function (x, ...)
 decompose.hhh4 <- function (x, coefs = x$coefficients, ...)
 {
     ## get three major components from meanHHH() function
-    meancomps <- meanHHH(coefs, terms.hhh4(x))
+    meancomps <- meanHHH(coefs, terms(x))
 
     ## this contains c("endemic", "epi.own", "epi.neighbours")
     ## but we really want the mean by neighbour
@@ -567,7 +580,7 @@ neOffsetArray <- function (object, pars = coefW(object),
         }
         ## stopifnot(all.equal(
         ##     colSums(res),  # sum over j
-        ##     terms.hhh4(object)$offset$ne(pars)[subset,,drop=FALSE],
+        ##     terms(object)$offset$ne(pars)[subset,,drop=FALSE],
         ##     check.attributes = FALSE))
     }
 
