@@ -1,13 +1,11 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
+### Plot method(s) for fitted "hhh4" models
 ###
-### Plot-method(s) for fitted hhh4() models
+### Copyright (C) 2010-2012 Michaela Paul, 2012-2023 Sebastian Meyer
 ###
-### Copyright (C) 2010-2012 Michaela Paul, 2012-2020 Sebastian Meyer
-### $Revision: 2511 $
-### $Date: 2020-01-10 10:08:18 +0100 (Fri, 10. Jan 2020) $
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 
@@ -40,6 +38,7 @@ plotHHH4_fitted <- function (x, units = 1, names = NULL,
                              legend.observed = FALSE,
                              decompose = NULL, total = FALSE, meanHHH = NULL, ...)
 {
+    stopifnot(inherits(x, "hhh4"))
     if (total) {
         units <- "Overall"  # only used as a label
     } else if (is.null(units)) {
@@ -51,7 +50,7 @@ plotHHH4_fitted <- function (x, units = 1, names = NULL,
     ## get decomposed mean => no need to compute it in each plotHHH4_fitted1()
     if (is.null(meanHHH)) {
         meanHHH <- if (is.null(decompose)) {
-            meanHHH(x$coefficients, terms.hhh4(x))
+            meanHHH(x$coefficients, terms(x))
         } else {
             decompose.hhh4(x)
         }
@@ -138,6 +137,7 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
                              xlim=NULL, ylim=NULL, xlab="", ylab="No. infected",
                              hide0s=FALSE, decompose=NULL, total=FALSE, meanHHH=NULL)
 {
+    stopifnot(inherits(x, "hhh4"))
     stsObj <- x$stsObj
     if (!total && is.character(unit) &&
         is.na(unit <- match(.unit <- unit, colnames(stsObj))))
@@ -162,7 +162,7 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
     tpInSubset <- intersect(x$control$subset, tpInRange)   # fitted time points
 
     ## use time indexes as x-values for use of addFormattedXAxis()
-    if (is.list(xaxis)) {
+    if (is.list(xaxis) || identical(xaxis, NA)) {
         tp <- seq_along(obs)
         start <- tpInRange[1L]
         end <- tpInRange[length(tpInRange)]
@@ -171,7 +171,7 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
     ## get fitted component means
     if (is.null(meanHHH)) {
         meanHHH <- if (is.null(decompose)) {
-            meanHHH(x$coefficients, terms.hhh4(x))
+            meanHHH(x$coefficients, terms(x))
         } else {
             decompose.hhh4(x)
         }
@@ -194,11 +194,6 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
     stopifnot(is.matrix(meanHHHunit), !is.null(colnames(meanHHHunit)),
               nrow(meanHHHunit) == length(x$control$subset))
     meanHHHunit <- meanHHHunit[x$control$subset %in% tpInRange,,drop=FALSE]
-    if (any(is.na(meanHHHunit))) { # -> polygon() would be wrong
-        ## could be due to wrong x$control$subset wrt the epidemic lags
-        ## a workaround is then to set 'start' to a later time point
-        stop("predicted mean contains missing values")
-    }
 
     ## check color vector
     col <- if (is.null(decompose) && length(col) == 4L) {
@@ -212,8 +207,9 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
     ## establish basic plot window
     if (is.null(ylim)) ylim <- c(0, max(obs[tpInRange],na.rm=TRUE))
     plot(c(start,end), ylim, xlim=xlim, xlab=xlab, ylab=ylab, type="n",
-         xaxt = if (is.list(xaxis)) "n" else "s")
-    if (is.list(xaxis)) do.call("addFormattedXAxis", c(list(x = stsObj), xaxis))
+         xaxt = if (is.list(xaxis)) "n" else par("xaxt"))
+    if (is.list(xaxis))
+        do.call(addFormattedXAxis, c(list(x = stsObj), xaxis))
     title(main=main, line=0.5)
 
     ## draw polygons
@@ -242,27 +238,42 @@ plotHHH4_fitted1 <- function(x, unit=1, main=NULL,
 
 plotComponentPolygons <- function (x, y, col = 1:6, border = col, add = FALSE)
 {
-    if (!is.vector(x, mode = "numeric") || is.unsorted(x, strictly = TRUE))
+    if (!is.vector(x, mode = "numeric") || length(x) == 0 ||
+        is.unsorted(x, strictly = TRUE))
         stop("'x' must be a strictly increasing sequence of time points")
-    stopifnot(nrow(y <- as.matrix(y)) == (nTime <- length(x)))  # y >= 0
+    stopifnot(is.numeric(y),  # y >= 0
+              nrow(y <- as.matrix(y)) == (nTime <- length(x)))
     yc <- if ((nPoly <- ncol(y)) > 1L) {
-        apply(X = y, MARGIN = 1L, FUN = cumsum) # nPoly x nTime
+        apply(X = y, MARGIN = 1L, FUN = function(comps)
+            if (anyNA(comps)) `is.na<-`(comps) else cumsum(comps)) # nPoly x nTime
     } else t(y)
 
     if (!add) {
         ## establish basic plot window
-        plot(range(x), range(yc[nPoly,]), type = "n")
+        plot(range(x), c(0, max(yc[nPoly,], na.rm = TRUE)), type = "n")
     }
 
     ## recycle graphical parameters
     col <- rep_len(col, nPoly)
     border <- rep_len(border, nPoly)
 
-    ## draw polygons
-    xpoly <- c(x[1L], x, x[length(x)])
+    ## draw 0-anchored polygons (piecewise if y contains missing values)
+    draw1 <- function (x, y, col, border) {
+        if (!is.na(nextNA <- match(NA_real_, y))) {
+            if (nextNA < length(y)) {
+                remainder <- (nextNA+1L):length(y)
+                draw1(x[remainder], y[remainder], col, border)
+            }
+            if (nextNA == 1L) return(invisible())
+            x <- x[seq_len(nextNA-1L)]
+            y <- y[seq_len(nextNA-1L)]
+        }
+        ## cat("drawing from x =", paste0(range(x), collapse=" to "), "\n")
+        polygon(c(x[1L], x, x[length(x)]), y = c(0, y, 0),
+                col = col, border = border)
+    }
     for (poly in nPoly:1) {
-        polygon(x = xpoly, y = c(0, yc[poly, ], 0),
-                col = col[poly], border = border[poly])
+        draw1(x, yc[poly, ], col[poly], border[poly])
     }
 }
 
@@ -275,15 +286,17 @@ plotHHH4_maps <- function (x,
     which = c("mean", "endemic", "epi.own", "epi.neighbours"),
     prop = FALSE, main = which, zmax = NULL, col.regions = NULL,
     labels = FALSE, sp.layout = NULL, ...,
-    map = x$stsObj@map, meanHHH = NULL)
+    map = x$stsObj@map,  ## aspect = mapasp(map), # currently hard-coded
+    meanHHH = NULL)
 {
+    stopifnot(inherits(x, "hhh4"))
     which <- match.arg(which, several.ok = TRUE)
     if (is.null(col.regions))
         col.regions <- .hcl.colors(10)
 
     ## extract district-specific mean components
     if (is.null(meanHHH)) {
-        meanHHH <- meanHHH(x$coefficients, terms.hhh4(x))
+        meanHHH <- meanHHH(x$coefficients, terms(x))
     }
 
     ## select relevant components and convert to an array
@@ -332,11 +345,13 @@ plotHHH4_maps <- function (x,
         if (is.na(zmax)) { # automatic color breaks over range of values
             spplot(map, zcol = zcol, main = main,
                    cuts = length(col.regions) - 1L,
-                   col.regions = col.regions, sp.layout = sp.layout, ...)
+                   col.regions = col.regions, sp.layout = sp.layout,
+                   aspect = mapasp(map), ...)
         } else { # breakpoints from 0 to zmax
             spplot(map, zcol = zcol, main = main,
                    at = seq(0, zmax, length.out = length(col.regions) + 1L),
-                   col.regions = col.regions, sp.layout = sp.layout, ...)
+                   col.regions = col.regions, sp.layout = sp.layout,
+                   aspect = mapasp(map), ...)
         },
         zcol = names(comps), main = main, zmax = zmax,
         SIMPLIFY = FALSE, USE.NAMES = FALSE)
@@ -356,9 +371,11 @@ plotHHH4_maps <- function (x,
 plotHHH4_ri <- function (x, component, exp = FALSE,
                          at = list(n = 10), col.regions = cm.colors(100),
                          colorkey = TRUE, labels = FALSE, sp.layout = NULL,
+                         ## aspect = mapasp(map), # currently hard-coded
                          gpar.missing = list(col="darkgrey", lty=2, lwd=2),
                          ...)
 {
+    stopifnot(inherits(x, "hhh4"))
     ranefmatrix <- ranef.hhh4(x, tomatrix=TRUE)
     if (is.null(ranefmatrix)) stop("model has no random effects")
     stopifnot(length(component) == 1L)
@@ -369,26 +386,51 @@ plotHHH4_ri <- function (x, component, exp = FALSE,
     map <- as(x$stsObj@map, "SpatialPolygonsDataFrame")
     if (length(map) == 0L) stop("'x$stsObj' has no map")
     map$ranef <- ranefmatrix[,comp][row.names(map)]
-    .range <- c(-1, 1) * max(abs(map$ranef), na.rm = TRUE)  # 0-centered
-    if (exp) {
-        map$ranef <- exp(map$ranef)
-        .range <- exp(.range)
-    }
 
     if (is.list(at)) {
-        at <- modifyList(list(n = 10, range = .range), at)
-        at <- if (exp) {
-            stopifnot(at$range[1] > 0)
-            scales::log_breaks(n = at$n)(at$range)
-        } else {
-            seq(at$range[1L], at$range[2L], length.out = at$n)
+        if (is.null(at[["n"]]))
+            at$n <- 10
+        if (is.null(at[["range"]])) {
+            at$range <- c(-1, 1) * max(abs(map$ranef), na.rm = TRUE)  # 0-centered
+        } else if (exp) { # custom range given on exp-scale
+            stopifnot(at$range > 0)
+            at$range <- log(at$range)
         }
-        if (exp && isTRUE(colorkey))
-            colorkey <- list(at = log(at),
-                             labels = list(at = log(at), labels = at))
+        at <- seq(at$range[1L], at$range[2L], length.out = at$n)
+        ## include max value (levelplot uses right-open intervals)
+        at[length(at)] <- at[length(at)] + sqrt(.Machine$double.eps)
+    } else {
+        stopifnot(is.numeric(at), length(at) > 2)
+        if (exp) { # custom breaks given on exp-scale
+            stopifnot(at > 0)
+            at <- log(at)
+        }
+    }
+    rng <- range(map$ranef, na.rm = TRUE)
+    if (rng[1] < at[1] | rng[2] >= at[length(at)]) {
+        if (exp) rng <- exp(rng)
+        warning(paste0(
+            sprintf("color breaks ('at') do not span range of data (%.3g,%.3g)",
+                    rng[1], rng[2]),
+            if (exp) " (exp-scale)"))
     }
 
-    if (is.list(gpar.missing) && any(is.na(map$ranef))) {
+    if (isTRUE(colorkey)) colorkey <- list()
+    if (exp && is.list(colorkey) && is.null(colorkey[["labels"]])) {
+        ## use exp-scale axis labels
+        if (is.null(nint <- colorkey[["tick.number"]]))
+            nint <- 7
+        lab <- if (requireNamespace("scales", quietly = TRUE)) {
+            scales::log_breaks(n = nint)(exp(at))
+        } else {
+            axisTicks(log10(exp(range(at))), log = TRUE, nint = nint)
+        }
+        ## workaround colorkey labeling bug in lattice (see https://github.com/deepayan/lattice/pull/22)
+        lab <- lab[log(lab) > at[1]]
+        colorkey$labels <- list(at = log(lab), labels = lab)
+    }
+
+    if (is.list(gpar.missing) && anyNA(map$ranef)) {
         sp.layout <- c(sp.layout,
                        c(list("sp.polygons", map[is.na(map$ranef),]),
                          gpar.missing))
@@ -399,7 +441,7 @@ plotHHH4_ri <- function (x, component, exp = FALSE,
 
     spplot(map[!is.na(map$ranef),], zcol = "ranef",
            sp.layout = sp.layout, col.regions = col.regions,
-           at = at, colorkey = colorkey, ...)
+           at = at, colorkey = colorkey, aspect = mapasp(map), ...)
 }
 
 
@@ -456,6 +498,7 @@ plotHHH4_maxEV <- function (...,
 
 getMaxEV <- function (x)
 {
+    stopifnot(inherits(x, "hhh4"))
     Lambda <- createLambda(x)
     if (identical(type <- attr(Lambda, "type"), "zero")) {
         rep.int(0, nrow(x$stsObj))
@@ -516,8 +559,7 @@ get_exppreds_with_offsets <- function (object,
                                        subset = seq_len(nrow(object$stsObj)),
                                        theta = object$coefficients)
 {
-    model <- terms.hhh4(object)
-    means <- meanHHH(theta, model, subset = subset)
+    means <- meanHHH(theta, terms(object), subset = subset)
     res <- sapply(X = c("ar", "ne", "end"), FUN = function (comp) {
         exppred <- means[[paste0(comp, ".exppred")]]
         offset <- object$control[[comp]]$offset
@@ -566,11 +608,13 @@ plotHHH4_season <- function (...,
                              xlab = NULL, ylab = "", main = NULL,
                              par.settings = list(), matplot.args = list(),
                              legend = NULL, legend.args = list(),
-                             refline.args = list(), unit = 1)
+                             refline.args = list(), unit = 1,
+                             period = NULL) # for harmonics with period > freq
 {
     objnams <- unlist(lapply(match.call(expand.dots=FALSE)$..., deparse))
     objects <- getHHH4list(..., .names = objnams)
     freq <- attr(objects, "freq")
+    if (is.null(period)) period <- freq
     components <- if (is.null(components)) {
         intersect(c("end", "ar", "ne"), unique(unlist(
             lapply(objects, componentsHHH4), use.names = FALSE)))
@@ -580,8 +624,6 @@ plotHHH4_season <- function (...,
     }
 
     ## x-axis
-    if (is.null(xlim))
-        xlim <- c(1,freq)
     if (is.null(xlab))
         xlab <- if (freq==52) "week" else if (freq==12) "month" else "time"
 
@@ -648,13 +690,14 @@ plotHHH4_season <- function (...,
     ## plot seasonality in individual model components
     seasons <- list()
     for(comp in setdiff(components, "maxEV")){
-        s2 <- lapply(objects, getSeason, component = comp, unit = unit)
+        s2 <- lapply(objects, getSeason, component = comp,
+                     unit = unit, period = period)
         seasons[[comp]] <- exp(vapply(s2, FUN = if (intercept) {
             function (intseas) do.call("+", intseas)
         } else {
             function (intseas) intseas$season  # disregard intercept
-        }, FUN.VALUE = numeric(freq), USE.NAMES = TRUE))
-        do.call("matplot",              # x defaults to 1:freq
+        }, FUN.VALUE = numeric(period), USE.NAMES = TRUE))
+        do.call("matplot",              # x defaults to 1:period
                 c(list(seasons[[comp]], xlim=xlim, ylim=ylim[[comp]],
                        xlab=xlab, ylab=ylab[[comp]], main=main[[comp]]),
                   matplot.args))
@@ -668,8 +711,8 @@ plotHHH4_season <- function (...,
     ## plot seasonality of dominant eigenvalue
     if ("maxEV" %in% components) {
         seasons[["maxEV"]] <- vapply(objects, FUN = function (obj) {
-            getMaxEV_season(obj)$maxEV.season
-        }, FUN.VALUE = numeric(freq), USE.NAMES = TRUE)
+            getMaxEV_season(obj, period = period)$maxEV.season
+        }, FUN.VALUE = numeric(period), USE.NAMES = TRUE)
         do.call("matplot",
                 c(list(seasons[["maxEV"]], xlim=xlim,
                        ylim=if (is.null(ylim[["maxEV"]]))
@@ -691,17 +734,16 @@ plotHHH4_season <- function (...,
 # get estimated intercept and seasonal pattern in the different components
 # CAVE: other covariates and offsets are ignored
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-getSeason <- function(x, component = c("end", "ar", "ne"), unit = 1)
+getSeason <- function(x, component = c("end", "ar", "ne"), unit = 1,
+                      period = x$stsObj@freq)
 {
-    stopifnot(inherits(x, "hhh4"))
     component <- match.arg(component)
     startseason <- getSeasonStart(x)
-    freq <- x$stsObj@freq
     if (is.character(unit)) unit <- match(unit, colnames(x$stsObj))
 
     ## return -Inf is component is not in the model (-> exp(-Inf) = 0)
     if (!component %in% componentsHHH4(x))
-        return(list(intercept=-Inf, season=rep.int(-Inf, freq)))
+        return(list(intercept=-Inf, season=rep.int(-Inf, period)))
 
     ## get the intercept
     est <- fixef.hhh4(x, reparamPsi=FALSE)
@@ -726,12 +768,12 @@ getSeason <- function(x, component = c("end", "ar", "ne"), unit = 1)
         names(coefSinCos) <- sub("\\)\\..+$", ")", names(coefSinCos))
     }
     if (length(coefSinCos)==0)
-        return(list(intercept=intercept, season=rep.int(0,freq)))
+        return(list(intercept=intercept, season=rep.int(0,period)))
     fSinCos <- reformulate(
         sub(paste0("^",component,"\\."), "", names(coefSinCos)),
         intercept=FALSE)
     mmSinCos <- model.matrix(fSinCos,
-                             data=data.frame(t=startseason-1 + seq_len(freq)))
+                             data=data.frame(t=startseason-1 + seq_len(period)))
 
     ## Done
     list(intercept=intercept, season=as.vector(mmSinCos %*% coefSinCos))
@@ -742,11 +784,10 @@ getSeason <- function(x, component = c("end", "ar", "ne"), unit = 1)
 # compute dominant eigenvalue of Lambda_t
 # CAVE: no support for Lambda_it
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-getMaxEV_season <- function (x)
+getMaxEV_season <- function (x, period = x$stsObj@freq)
 {
     stopifnot(inherits(x, "hhh4"))
     nUnits <- x$nUnit
-    freq <- x$stsObj@freq
     components <- componentsHHH4(x)
 
     ## CAVE: this function ignores epidemic covariates/offsets
@@ -796,16 +837,16 @@ getMaxEV_season <- function (x)
         Lambda
     }
 
-    ## do this for t in 0:freq
+    ## do this for t in 0:period
     diagonal <- !("ne" %in% components)
     .maxEV <- function (t) {
         maxEV(createLambda(t), symmetric = FALSE, diagonal = diagonal)
     }
     maxEV.const <- .maxEV(0)
     maxEV.season <- if (all(c(s2.phi$season, s2.lambda$season) %in% c(-Inf, 0))) {
-        rep.int(maxEV.const, freq)
+        rep.int(maxEV.const, period)
     } else {
-        vapply(X = seq_len(freq), FUN = .maxEV, FUN.VALUE = 0, USE.NAMES = FALSE)
+        vapply(X = seq_len(period), FUN = .maxEV, FUN.VALUE = 0, USE.NAMES = FALSE)
     }
 
     ## Done
