@@ -1,13 +1,11 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Simulate from a "twinSIR" model as described in Hoehle (2009)
 ###
-### Copyright (C) 2009 Michael Hoehle, 2009, 2012, 2014, 2019 Sebastian Meyer
-### $Revision: 2497 $
-### $Date: 2019-11-04 11:03:50 +0100 (Mon, 04. Nov 2019) $
+### Copyright (C) 2009 Michael Hoehle, 2009,2012,2014,2019,2021 Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 ## Apart from simulation of SIR data, it is possible to simulate
@@ -55,7 +53,7 @@ simEpidata <- function (formula, data, id.col, I0.col, coords.cols,
             colidx <- get(colarg, inherits = FALSE)
             if (is.numeric(colidx)) {
                 tmp <- names(data)[colidx]
-                if (any(is.na(tmp))) {
+                if (anyNA(tmp)) {
                     stop("'", colarg, " = ", deparse(cl[[colarg]]), "': ",
                          "column index must be in [1; ", ncol(data),
                          "=ncol(data)]")
@@ -185,7 +183,7 @@ simEpidata <- function (formula, data, id.col, I0.col, coords.cols,
                 "(number of epidemic terms), must be specified"), nPredEpi))
         }
         alpha <- alpha[c(names(f), names(w))]
-        if (any(is.na(alpha))) {
+        if (anyNA(alpha)) {
             stop("'alpha' is incomplete for 'f' or 'w'")
         }
         stopifnot(alpha >= 0)
@@ -217,8 +215,7 @@ simEpidata <- function (formula, data, id.col, I0.col, coords.cols,
         }
         h0ChangePoints <- knots(h0$upper)
     } else if (isScalar(h0)) {
-        h0func <- eval(parse(text = paste("function (t)", h0)))
-        environment(h0func) <- parent.frame()
+        h0func <- as.function(c(alist(t=), list(h0)), envir = .GlobalEnv)
         h0 <- list(exact = h0func, upper = h0func)
         h0ChangePoints <- numeric(0L)
     } else {
