@@ -1,14 +1,12 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Maximum Likelihood inference for the two-component spatio-temporal intensity
 ### model described in Meyer et al (2012), DOI: 10.1111/j.1541-0420.2011.01684.x
 ###
 ### Copyright (C) 2009-2019 Sebastian Meyer
-### $Revision: 2460 $
-### $Date: 2019-07-19 17:42:18 +0200 (Fri, 19. Jul 2019) $
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 
@@ -41,6 +39,7 @@ twinstim <- function (
     epilinkinv <- switch(epilink, "log" = exp, "identity" = identity)
 
     ## Clean the model environment when exiting the function
+    if (model)
     on.exit(suppressWarnings(rm(cl, cumCIF, cumCIF.pb, data, doHessian,
         eventsData, finetune, neghess, fisherinfo, fit, fixed,
         functions, globalEndemicIntercept, inmfe, initpars,
