@@ -1,14 +1,12 @@
 ################################################################################
-### Part of the surveillance package, http://surveillance.r-forge.r-project.org
-### Free software under the terms of the GNU General Public License, version 2,
-### a copy of which is available at http://www.r-project.org/Licenses/.
-###
 ### Methods for objects of class "twinstim", specifically:
 ### vcov, logLik, print, summary, plot, R0, residuals, update, terms, all.equal
 ###
-### Copyright (C) 2009-2019 Sebastian Meyer
-### $Revision: 2461 $
-### $Date: 2019-07-19 17:49:32 +0200 (Fri, 19. Jul 2019) $
+### Copyright (C) 2009-2019,2022 Sebastian Meyer
+###
+### This file is part of the R package "surveillance",
+### free software under the terms of the GNU General Public License, version 2,
+### a copy of which is available at https://www.R-project.org/Licenses/.
 ################################################################################
 
 ## extract the link function used for the epidemic predictor (default: log-link)
@@ -245,7 +243,7 @@ ret <- capture.output({
                 ifelse(is.na(x), "", paste0("$",x,"$")) # (test.iaf=FALSE)
             })
             cat(if (booktabs) "\\midrule" else "\\hline", "\n")
-            print(xtable(tab2), only.contents=TRUE, hline.after=NULL,
+            print(xtable(tab2), only.contents=TRUE, hline.after=NULL, comment=FALSE,
                   include.colnames=FALSE, sanitize.text.function=identity)
         }
     }
@@ -690,7 +688,7 @@ profile.twinstim <- function (fitted, profile, alpha = 0.05,
     if (is.na(profile[[i]][3])) profile[[i]][3] <- theta.ml[idx] + 3*se[idx]
     #Evaluate profile loglik on a grid (if requested)
     if (profile[[i]][4] > 0) {
-      thetai.grid <- seq(profile[[i]][2],profile[[i]][3],length=profile[[i]][4])
+      thetai.grid <- seq(profile[[i]][2],profile[[i]][3],length.out=profile[[i]][4])
       resProfile[[i]] <- matrix(NA, nrow = length(thetai.grid), ncol = 4L,
         dimnames = list(NULL, c("grid","profile","estimated","wald")))
 
@@ -842,5 +840,17 @@ all.equal.twinstim <- function (target, current, ..., ignore = NULL)
 
     ignore <- unique.default(c(ignore, "runtime", "call"))
     target[ignore] <- current[ignore] <- list(NULL)
+
+    ## also ignore siaf.step() cache ("cachem" is time-dependent)
+    drop_cache <- function (siaf) {
+        isStepFun <- !is.null(knots <- attr(siaf, "knots")) &&
+            !is.null(maxRange <- attr(siaf, "maxRange"))
+        if (isStepFun) {
+            structure(list(), knots = knots, maxRange = maxRange)
+        } else siaf
+    }
+    target$formula$siaf <- drop_cache(target$formula$siaf)
+    current$formula$siaf <- drop_cache(current$formula$siaf)
+
     NextMethod("all.equal")
 }
